import 'package:http/http.dart' as http;
import 'dart:convert';

class ApiClient {
  final String dataBaseUrl = "https://data.mentor.iblai.tech";

  Future<dynamic> apiAiAccountOrgsOrgCredentialGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgCredentialPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgCredentialPatch(String? org, Map body) async {
    final response = await http.patch(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/credential/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgPlatformMetadataPut(String? org, Map body) async {
    final response = await http.put(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/platform-metadata/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiAccountOrgsOrgTokensGet(String? org) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/account/orgs/$org/tokens/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsGet(String? documentId, String? org, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/documents/$documentId/retriever_documents/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdDocumentsDocumentIdRetrieverDocumentsPut(String? documentId, String? org, String? userId, Map body) async {
    final response = await http.put(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/documents/$documentId/retriever_documents/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdMultilingualRetrieverTrainPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/multilingual_retriever_train/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdPathwaysPathwayRetrieverDocumentsGet(String? org, String? pathway, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/pathways/$pathway/retriever_documents/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdRetrieverSearchPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/retriever_search/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdRetrieverTrainPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/retriever_train/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdSourcesPost(String? org, String? userId, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/sources/'),
      body: json.encode(body),
      headers: {'Content-Type': 'application/json'},
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiIndexOrgsOrgUsersUserIdTasksTaskIdGet(String? org, String? taskId, String? userId) async {
    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/index/orgs/$org/users/$userId/tasks/$taskId/'),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgUsersUserIdGet({
    required String? org,
    int? page,
    int? pageSize,
    required String? userId,
    bool? featured, // Optional featured parameter
  }) async {
    var queryParams = {
      if (page != null) 'page': page.toString(),
      if (pageSize != null) 'pageSize': pageSize.toString(),
      if (featured != null) 'featured': featured.toString(), // Add featured to query params if not null
    };

    var queryString = Uri(queryParameters: queryParams).query;

    final response = await http.get(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/users/$userId/?$queryString'),
      headers: _headers(),
    );
    return json.decode(response.body);
  }

  Future<dynamic> apiAiMentorOrgsOrgMentorWithSettingsPost(String? org, Map body) async {
    final response = await http.post(
      Uri.parse('$dataBaseUrl/api/ai/mentor/orgs/$org/mentor-with-settings/'),
      body: json.encode(body),
    );
    return json.decode(response.body);
  }
}
